Learn R Programming

httkexamples (version 0.0.1)

wambaugh2019.seem3: ExpoCast SEEM3 Consensus Exposure Model Predictions for Chemical Intake Rates

Description

These data are a subset of the Bayesian inferences reported by Ring et al. (2019) (tools:::Rd_expr_doi("10.1021/acs.est.8b04056")) for a consensus model of twelve exposure predictors. The predictors were calibrated based upon their ability to predict intake rates inferred National Health and Nutrition Examination Survey (NHANES). They reflect the population median intake rate (mg/kg body weight/day), with uncertainty.

These data are a subset of the Bayesian inferrences reported by Ring et al. (2019) for a consensus model of twelve exposue predictors. The predictors were calibrated based upon their ability to predict intake rates inferred National Health and Nutrition Examination Survey (NHANES). They reflect the populaton median intake rate (mg/kg body weight/day), with uncertainty.

Usage

wambaugh2019.seem3

wambaugh2019.seem3

Arguments

Format

A data frame with 385 rows and 38 variables:

A data frame with 385 rows and 38 variables:

Author

John Wambaugh

References

Ring2017SEEMhttkexamples

wambaugh2019assessinghttkexamples

Ring2017SEEMhttkexamples

wambaugh2019assessinghttkexamples